@@ -1,6 +1,6 @@
 %%% -*- coding: utf-8; erlang-indent-level: 2 -*-
 %%% -------------------------------------------------------------------
-%%% Copyright 2010-2021 Manolis Papadakis <manopapad@gmail.com>,
+%%% Copyright 2010-2023 Manolis Papadakis <manopapad@gmail.com>,
 %%%                     Eirini Arvaniti <eirinibob@gmail.com>,
 %%%                 and Kostis Sagonas <kostis@cs.ntua.gr>
 %%%
@@ -19,7 +19,7 @@
 %%% You should have received a copy of the GNU General Public License
 %%% along with PropEr.  If not, see <http://www.gnu.org/licenses/>.
 
-%%% @copyright 2010-2021 Manolis Papadakis, Eirini Arvaniti, and Kostis Sagonas
+%%% @copyright 2010-2023 Manolis Papadakis, Eirini Arvaniti, and Kostis Sagonas
 %%% @version {@version}
 %%% @author Manolis Papadakis
 
@@ -104,7 +104,7 @@
 %%%   where:
 %%%   ``` -type rec() :: #rec{}.
 %%%       -record(rec, {a = 0 :: integer(), b = 'nil' :: 'nil' | #rec{}}). '''
-%%%   A little rewritting can usually remedy this problem as well:
+%%%   A little rewriting can usually remedy this problem as well:
 %%%   ``` ?FORALL(..., rec(), ...) '''
 %%%   where:
 %%%   ``` -type rec() :: #rec{b :: 'nil'} | #rec{b :: rec()}.
@@ -513,9 +513,8 @@ apply_spec_test({Mod,Fun,_Arity}=MFA, {_Domain,Range}, SpecTimeout, FalsePositiv
 		   try apply(Mod, Fun, Args) of
 		       X -> {{ok, X}, none}
 		   catch
-		       ?STACKTRACE(X, Y, Trace) %, is in macro
-		       {{X, Y}, Trace}
-		       end,
+		       Class:Reason:Trace -> {{Class, Reason}, Trace}
+		   end,
 	       case Result of
 		   {ok, Z} ->
 		       case ?MODULE:is_instance(Z, Mod, Range) of
@@ -2168,7 +2167,7 @@ expr_error(Reason, Expr1, Expr2) ->
 
 -spec base_case_error(stack()) -> {'error',term()}.
 %% TODO: This might confuse, since it doesn't record the arguments to parametric
-%%	 types or the type subsitutions of a record.
+%%	 types or the type substitutions of a record.
 base_case_error([{Mod,type,Name,Args} | _Upper]) ->
     Arity = length(Args),
     {error, {no_base_case,{Mod,type,Name,Arity}}};
